@@ -3,9 +3,11 @@ package App::MyPerl::Rewrite;
 use Moo;
 use IO::All;
 
-extends 'App::MyPerl';
+with 'App::MyPerl::Role::Script';
 
-has file_preamble => (is => 'lazy', builder => sub {
+sub use_files { qw(modules) }
+
+has exclude_dev_preamble => (is => 'lazy', builder => sub {
   join "\n", @{$_[0]->preamble},
 });
 
@@ -16,7 +18,8 @@ sub run {
 
 sub rewrite_dir {
   my ($self, $dir) = @_;
-  my $preamble = $self->file_preamble;
+  my $preamble = $self->exclude_dev_preamble;
+  print $preamble . "\n" if $self->_env_value('DEBUG');
   foreach my $file (io->dir($dir)->all_files(0)) {
     next unless $file->name =~ /\.pm$|\.t$|^${dir}\/bin\//;
     my $data = $file->all;
